/************************************************************************
 *                                                                      *
 * File:        my_stubs.c		                                *
 *                                                                      *
 * Author(s):   T. Frivold, D.Beyer.  Rooftop Communications.           *
 *                                                                      *
 * Description: Skeletal code for Radio Device                          *
 * 		Stub routines.						*
 *                                                                      *
 *                                                                      *
 ************************************************************************/

#include <my_rad.h>
#include <my_radpr.h>	/* Private, hardware specific functions/values */

typedef struct
{
    IntHandlerFp	  handler;
    void		* devPtr;
} IntHandlerInfoType;

static IntHandlerInfoType _IntHandlerInfo;  

static uint32             _XmtActive  	= 0;

static uint32		  _XmtQFull 	= 0;
static uint32		  _RcvQFull 	= 0;

static MyRadioPktInfo   * _XmtQBuf 	= (void *)0;
static MyRadioPktInfo   * _RcvQBuf 	= (void *)0;

static MyRadioPktInfo     _InfoList[16];
static uint32		  _InfoNum 	= 0;

void
_EnableInterrupts(void)
{
    /* enable interrupts */
}

void
_DisableInterrupts(void)
{
    /* disable interrupts */
}

void
_InterruptEnable(uint32 intNum)
{
    /* enable interrupt intNum */
}

void
_InterruptDisable(uint32 intNum)
{
    /* disable interrupt intNum */
}


void
_RegisterInteruptHandler( IntHandlerFp intFunc, void * dev /* other args.. */)
{
    _IntHandlerInfo.handler = intFunc;
    _IntHandlerInfo.devPtr  = dev;
}

/* Self explanator functions */
void
_TurnOffTransmitter(void)
{
    /* turn off transmitter */
    _XmtActive = 0;
}

void
_TurnOnTransmitter(void)
{
    /* turn on transmitter */
    _XmtActive = 1;
}

uint32
_TransmitterOff(void)
{
    return(_XmtActive == 0);
}

uint32
_XmtQEmpty(void)
{
    return(_XmtQFull == 0);
}

void
_XmtPkt(MyRadioPktInfo *myInfo)
{
    /* receive signal carrier on */
    ( *(_IntHandlerInfo.handler) )( _IntHandlerInfo.devPtr, 
				    interruptRcvCarrierOn, 
				    (void *)0, 0);

    /* make sure that rcv buffer is valid, then ... */

    /* loop back packet into receive buffer */
    strcpy( ((DevPktInfo *)_RcvQBuf)->buf, ((DevPktInfo *)myInfo)->buf );

    _XmtQFull 	= 0; 

    /* signal that we're done transmitting the packet */
    ((RadioDevPktInfo *)myInfo)->errStatus = 0;
    ( *(_IntHandlerInfo.handler) )( _IntHandlerInfo.devPtr, 
				    interruptXmtPkt, 
				    myInfo, sizeof(MyRadioPktInfo) );

    _RcvQFull	= 0;

    /* signal that we've received a packet */
    ((RadioDevPktInfo *)_RcvQBuf)->errStatus = 0;
    ( *(_IntHandlerInfo.handler) )( _IntHandlerInfo.devPtr, 
				    interruptRcvPkt, 
				    _RcvQBuf, sizeof(MyRadioPktInfo) );


    /* signal carrier off */
    ( *(_IntHandlerInfo.handler) )( _IntHandlerInfo.devPtr, 
				    interruptRcvCarrierOff, 
				    (void *)0, 0);
}

void
_XmtQEnqueue(MyRadioPktInfo *pktInfo)
{
    /* check for overrun */

    _XmtQFull 	= 1;		/* (max xmt queue len is 1) */ 
    _XmtQBuf   	= pktInfo;
}

MyRadioPktInfo	*
_XmtQDequeue(void)
{
    _XmtQFull 	= 0;

    return _XmtQBuf;
}

void
_RcvQEnqueue(MyRadioPktInfo *pktInfo)
{
    _RcvQFull 	= 1;	 	  /* (max receive queue len is 1) */
    _RcvQBuf   	= pktInfo;
}

MyRadioPktInfo	*
_PktInfoPoolGet(void)
{
    /* check for overrun, then... */
 
    MyRadioPktInfo * info = &(_InfoList[_InfoNum]);

    _InfoNum ++;
    if (_InfoNum == 16) _InfoNum = 0;

    return info;
}

void
_PktInfoPoolPut(MyRadioPktInfo *pktInfo)
{
    /* return to list ... */
}
